'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _blessed = require('blessed');

var _blessed2 = _interopRequireDefault(_blessed);

var _buildColorsJs = require('./buildColors.js');

var _buildColorsJs2 = _interopRequireDefault(_buildColorsJs);

var request = require('request');

function buildHeader(serverUrl, onBack, axisList, screen, logWidget) {
  var header = _blessed2['default'].listbar({
    height: 'shrink', // : 3,
    mouse: true,
    width: '100%',
    keys: true,
    autoCommandKeys: true,
    border: 'line',
    vi: true,
    style: {
      // bg: 'green',
      item: {
        // bg: 'red',
        hover: {
          bg: 'blue'
        },
        focus: {
          bg: 'blue'
        }
      },
      selected: {
        bg: 'blue'
      }
    }
  });
  var commands = {
    '<---Back': {
      keys: ['b'],
      callback: onBack
    }
  };
  axisList.forEach(function (axis) {
    commands[_buildColorsJs2['default'](axis.result)(axis['script'])] = { callback: function callback() {
        loadLog(serverUrl + '/' + axis.url, onBack, logWidget, screen);
      } };
  });
  header.setItems(commands);
  return header;
}
function logWidget(parent) {
  var log = _blessed2['default'].log({
    scrollable: true,
    parent: parent,
    top: 2,
    alwaysScroll: true,
    tags: true,
    keys: true,
    vi: true,
    mouse: true,
    border: {
      type: 'line'
    },
    style: {
      fg: 'green',
      bg: 'black',
      border: {
        fg: 'blue'
      },
      scrollbar: {
        bg: 'blue'
      }
    }
  });
  log.focus();
  return log;
}
function loadLog(url, onBack, logWidget, screen) {
  request({
    uri: url + '/logTail'
  }, function (error, response, body) {
    if (!error && response.statusCode == 200) {
      logWidget.setContent(body);
      // screen.append(buildScreen);
      screen.render();
    } else {
      console.error(error);
    }
  });
}

exports['default'] = function (serverUrl, baseUrl, screen, buildNumber, axisList, onBack) {
  screen.key(['C-b'], function (ch, key) {
    onBack();
  });
  var log = logWidget(screen);
  var buildHeaderWidget = buildHeader(serverUrl, onBack, axisList, screen, log);
  screen.append(buildHeaderWidget);
  screen.render();

  var loading = _blessed2['default'].loading({
    // screen,
    top: 3,
    alwaysScroll: true
  });
  // loading.load("loading..");
  // screen.append(loading);
  // screen.render();

  loadLog(baseUrl + buildNumber, onBack, log, screen);
};

module.exports = exports['default'];