'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _buildJs = require('./build.js');

var _buildJs2 = _interopRequireDefault(_buildJs);

var _blessedContrib = require('blessed-contrib');

var _blessedContrib2 = _interopRequireDefault(_blessedContrib);

var _blessed = require('blessed');

var _blessed2 = _interopRequireDefault(_blessed);

var _buildColorsJs = require('./buildColors.js');

var _buildColorsJs2 = _interopRequireDefault(_buildColorsJs);

var request = require('request');

function buildRow(build) {
  var number = build.number;
  var displayTime = build.displayTime;
  var result = build.result;
  var commit = build.commit;
  var committerName = commit.committerName;
  var message = commit.message;
  var shortSha = commit.shortSha;
  var branch = commit.branch;

  var color = _buildColorsJs2['default'](result);
  var cols = [displayTime, result, branch, committerName, message, shortSha].map(function (col) {
    return color(col);
  });
  return [number + ''].concat(cols);
}
function buildHistoryWidget(serverUrl, repoName, screen, inputBuilds, onBack) {
  var url = getUrl(serverUrl, repoName);
  var builds = [];
  builds.push(['number', 'Ago', 'Result', 'Branch', 'Commiter', 'Message', 'Sha']);
  inputBuilds.forEach(function (build) {
    return builds.push(buildRow(build));
  });
  var table = _blessed2['default'].ListTable({
    parent: screen,
    screen: screen,
    width: '100%',
    height: '100%',
    border: {
      type: 'line',
      left: true,
      top: true,
      right: false,
      bottom: false
    },
    align: 'center',
    tags: true,
    keys: true,
    vi: true,
    mouse: true,
    noCellBorders: true,
    style: {
      header: {
        fg: 'blue',
        bold: true
      },
      cell: {
        fg: 'white',
        selected: {
          bg: 'blue'
        }
      }
    },
    rows: builds
  });
  table.builds = inputBuilds;
  table.on('select', function (item) {
    var number = item.parent.rows[item.parent.selected][0];
    var axisList = item.parent.builds[item.parent.selected - 1]['axisList'];
    _buildJs2['default'](serverUrl, url, screen, number, axisList, onBack);
  });
  table.focus();
}

function getUrl(serverUrl, repoName) {
  var org = repoName.split('/')[0];
  var repo = repoName.split('/')[1];
  return serverUrl + '/job/' + org + '/job/' + repo + '/';
}

exports['default'] = function (serverUrl, repoName, screen, onBack) {
  request({
    uri: getUrl(serverUrl, repoName) + 'api/json/',
    qs: {
      tree: "appData[info[buildHistoryTabs,builds[*,commit[*],cause[*],parameters[*]]]]",
      branchTab: 'All',
      count: 50
    }
  }, function (error, response, body) {
    if (!error && response.statusCode == 200) {
      var builds = JSON.parse(body)['appData']['info']['builds'];
      buildHistoryWidget(serverUrl, repoName, screen, builds, onBack);
      screen.render();
    } else {
      console.error(error);
    }
  });
};

module.exports = exports['default'];